@@ -20,6 +20,7 @@ class DeepWalkGloVeEnsmallen(Node2VecEnsmallen):
         central_nodes_embedding_path: Optional[str] = None,
         contextual_nodes_embedding_path: Optional[str] = None,
         normalize_by_degree: bool = False,
+        dtype: str = "f32",
         random_state: int = 42,
         enable_cache: bool = False
     ):
@@ -65,6 +66,8 @@ class DeepWalkGloVeEnsmallen(Node2VecEnsmallen):
         normalize_by_degree: bool = False
             Whether to normalize the random walk by the node degree
             of the destination node degrees.
+        dtype: str = "f32"
+            The data type to be employed, by default f32.
         random_state: int = 42
             The random state to reproduce the training sequence.
         enable_cache: bool = False
@@ -86,6 +89,7 @@ class DeepWalkGloVeEnsmallen(Node2VecEnsmallen):
             contextual_nodes_embedding_path=contextual_nodes_embedding_path,
             normalize_by_degree=normalize_by_degree,
             enable_cache=enable_cache,
+            dtype=dtype,
             random_state=random_state
         )
 
